#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-8zlccaMgwCfAn7I25O8Af3
key:                  coinbase-pro-0.9.3.2-8zlccaMgwCfAn7I25O8Af3
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  3769274c17ae821176c6dea809bba7a7
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-8zlccaMgwCfAn7I25O8Af3
depends:
    HsOpenSSL-0.11.7.10-9kri7ahha9VJFMbq4ZyN3U
    aeson-2.2.2.0-GWc1LmCE0o9Bpe9MYCbSNj
    aeson-casing-0.2.0.0-DLs2Al2M4g54G5UGIppc2B
    async-2.2.6-1mBgL12wSAHIlTk64oC4Cy base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-k5YuqnDFkIFZ07a6FiI2I exceptions-0.10.7
    http-api-data-0.6.1-IRtHeEwZOyVJlVCcCm7oQb
    http-client-0.7.19-CdoyGBdmx4CJG3r6obV7W1
    http-client-tls-0.3.6.4-AnHGLSahOg9HVl4h6a2CCE
    http-streams-0.8.9.9-5gZppP4yGmN8Lf9OYMybjv
    http-types-0.12.4-7VF1fWYoZaw5btElYXN8F2
    io-streams-1.5.2.2-4indnnx6VhQ9OVPz2yY1ED
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-8EWNGK0wrm0Kwyfl1vrVL3
    servant-0.20.3.0-FSEVDRZsNnI7RGDMB6uNSg
    servant-client-0.20.3.0-EVJqYJQ5tzpIjPgF4vCYE7
    servant-client-core-0.20.3.0-2lUfDp5lGap5tdXp0wnndO
    tasty-1.5.3-6nKhUbFgil18EVkHRCvth3
    tasty-hunit-0.10.2-FFD9KlnFVgSCU5IQtw2gfR text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-7NeRV4ks9UN38uY34sAA5z
    unordered-containers-0.2.21-A5j6YbVJ6iQ4Gx0hziy0Dr
    uuid-1.3.16.1-9w5gGF1NPYRd1ESjCy9ko
    vector-0.13.2.0-HIEoUaJKlQrG3qeQBTxJjw
    websockets-0.12.7.3-FpURIjHhXSZ4b7P80lRZ1Q
    wuss-2.0.1.7-53MFwF95hXb2CBOY9I7Ake

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

